# py-ssz

[![Join the conversation on Discord](https://img.shields.io/discord/809793915578089484?color=blue&label=chat&logo=discord&logoColor=white)](https://discord.gg/GHryRvPB84)
[![Build Status](https://circleci.com/gh/ethereum/py-ssz.svg?style=shield)](https://circleci.com/gh/ethereum/py-ssz)
[![PyPI version](https://badge.fury.io/py/ssz.svg)](https://badge.fury.io/py/ssz)
[![Python versions](https://img.shields.io/pypi/pyversions/ssz.svg)](https://pypi.python.org/pypi/ssz)
[![Docs build](https://readthedocs.org/projects/ssz/badge/?version=latest)](https://ssz.readthedocs.io/en/latest/?badge=latest)

Python implementation of the Simple Serialization encoding and decoding

Read the [documentation](https://ssz.readthedocs.io/).

View the [change log](https://ssz.readthedocs.io/en/latest/release_notes.html).

## Installation

```sh
python -m pip install ssz
```
